==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/ScatterSplineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBase } from "./ScatterBase";
import { DependencyProperty } from "igniteui-react-core";
import { Point_$type, typeCast, runOn, markType, markDep } from "igniteui-react-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterSplineSeriesView } from "./ScatterSplineSeriesView";
import { Defaults } from "./Defaults";
import { Clipper } from "igniteui-react-core";
import { OwnedPoint } from "./OwnedPoint";
import { ScalerParams } from "./ScalerParams";
import { PathGeometry } from "igniteui-react-core";
import { Numeric } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
export let ScatterSplineSeries = /*@__PURE__*/ (() => {
    class ScatterSplineSeries extends ScatterBase {
        bj() {
            return new ScatterSplineSeries();
        }
        get_fz() {
            return true;
        }
        constructor() {
            super();
            this.ab = ScatterSplineSeries.$;
            this.yx = new ScatterFrame();
            this.yz = new ScatterFrame();
            this.yv = new ScatterFrame();
        }
        cr() {
            return new ScatterSplineSeriesView(this);
        }
        zr() {
            return true;
        }
        jj() {
            if (!isNaN_(this.ji)) {
                return super.jj();
            }
            return Defaults.x;
        }
        q7(a, b, c, d) {
            super.q7(a, b, c, d);
            switch (b) {
                case ScatterSplineSeries.$$p[0]:
                    this.rp(false);
                    this.qj();
                    break;
            }
        }
        b1() {
            if (this.b2 == 0) {
                return 2;
            }
            else {
                return super.b1();
            }
        }
        aba(a, b) {
            super.aba(a, b);
            a.m.clear();
            a.u.clear();
            let c = b.by;
            let d = b.bx;
            let e = this.getEffectiveViewport1(b);
            let f = this.ic * this.ic;
            let g = Math.min(this.zc != null ? this.zc.count : 0, this.zd != null ? this.zd.count : 0);
            let h = new ScalerParams(0, c, d, this.yr.d, e);
            let i = ((() => {
                let $ret = new ScalerParams(0, c, d, this.yr.e, e);
                $ret.b = this.ix();
                return $ret;
            })());
            let j = (k) => this.yr.a.ek(this.zc.item(k), h);
            let k = (l) => this.yr.b.ek(this.zd.item(l), i);
            let l = ((() => {
                let $ret = new Clipper(0, d, false);
                $ret.i = a.m;
                return $ret;
            })());
            for (let m = 0; m < g;) {
                let n = m;
                ++m;
                while (m < g && this.aci(j, k, n, m) < f) {
                    ++m;
                }
                if (g > this.z4) {
                    l.j(this.acm(j, k, n, m - 1));
                }
                else {
                    let o = new OwnedPoint();
                    o.c = { $type: Point_$type, x: j(n), y: k(n) };
                    o.a = this.dm.item(n);
                    if (!a.u.containsKey(o.a)) {
                        a.u.addItem(o.a, o);
                    }
                }
            }
            if (g > this.z4) {
                l.i = null;
            }
        }
        acm(a, b, c, d) {
            if (c == d) {
                return { $type: Point_$type, x: a(c), y: b(c) };
            }
            let e = 0;
            let f = 0;
            let g = (d - c + 1);
            for (let h = c; h <= d; ++h) {
                e += a(h);
                f += b(h);
            }
            return { $type: Point_$type, x: e / g, y: f / g };
        }
        aci(a, b, c, d) {
            let e = a(d) - a(c);
            let f = b(d) - b(c);
            return e * e + f * f;
        }
        get_zl() {
            return true;
        }
        o4(a, b) {
            super.o4(a, b);
            let c = typeCast(ScatterSplineSeriesView.$, b);
            c.c9(false);
        }
        abl(a, b) {
            this.o4(false, b);
            super.abl(a, b);
            this.abd(a);
            let c = typeCast(ScatterSplineSeriesView.$, b);
            let d = c.dl;
            this.y4.az(this, this.zq(), runOn(this, this.yk));
            let e = false;
            let f = this.y4.b;
            if (f != null) {
                e = true;
            }
            if (e) {
                this.aa6(-1, this.zc.count, b.q);
            }
            this.y4.ad(d, true, false, true, false);
            c.dl.an = new PathGeometry();
            c.dl.an.c = Numeric.h(a.m.count, (g) => a.m._inner[g].x, (g) => a.m._inner[g].y, this.acj);
        }
    }
    ScatterSplineSeries.$t = /*@__PURE__*/ markType(ScatterSplineSeries, 'ScatterSplineSeries', ScatterBase.$);
    ScatterSplineSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, ScatterSplineSeries, 'raisePropertyChanged', ['Stiffness:acj:acl', [1, 0.5]]);
    return ScatterSplineSeries;
})();

==> igniteui-react-charts-18.7.5-beta.0.tgz: package/esm2015/lib/ScatterSplineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBase } from "./ScatterBase";
import { DependencyProperty } from "igniteui-react-core";
import { Point_$type, typeCast, runOn, markType, markDep } from "igniteui-react-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterSplineSeriesView } from "./ScatterSplineSeriesView";
import { Defaults } from "./Defaults";
import { Clipper } from "igniteui-react-core";
import { OwnedPoint } from "./OwnedPoint";
import { ScalerParams } from "./ScalerParams";
import { PathGeometry } from "igniteui-react-core";
import { Numeric } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
export let ScatterSplineSeries = /*@__PURE__*/ (() => {
    class ScatterSplineSeries extends ScatterBase {
        bj() {
            return new ScatterSplineSeries();
        }
        get_f0() {
            return true;
        }
        constructor() {
            super();
            this.ab = ScatterSplineSeries.$;
            this.y0 = new ScatterFrame();
            this.y2 = new ScatterFrame();
            this.yy = new ScatterFrame();
        }
        cs() {
            return new ScatterSplineSeriesView(this);
        }
        zu() {
            return true;
        }
        jk() {
            if (!isNaN_(this.jj)) {
                return super.jk();
            }
            return Defaults.x;
        }
        q7(a, b, c, d) {
            super.q7(a, b, c, d);
            switch (b) {
                case ScatterSplineSeries.$$p[0]:
                    this.rp(false);
                    this.qj();
                    break;
            }
        }
        b2() {
            if (this.b3 == 0) {
                return 2;
            }
            else {
                return super.b2();
            }
        }
        abd(a, b) {
            super.abd(a, b);
            a.m.clear();
            a.u.clear();
            let c = b.by;
            let d = b.bx;
            let e = this.getEffectiveViewport1(b);
            let f = this.id * this.id;
            let g = Math.min(this.zf != null ? this.zf.count : 0, this.zg != null ? this.zg.count : 0);
            let h = new ScalerParams(0, c, d, this.yu.d, e);
            let i = ((() => {
                let $ret = new ScalerParams(0, c, d, this.yu.e, e);
                $ret.b = this.iy();
                return $ret;
            })());
            let j = (k) => this.yu.a.el(this.zf.item(k), h);
            let k = (l) => this.yu.b.el(this.zg.item(l), i);
            let l = ((() => {
                let $ret = new Clipper(0, d, false);
                $ret.i = a.m;
                return $ret;
            })());
            for (let m = 0; m < g;) {
                let n = m;
                ++m;
                while (m < g && this.acl(j, k, n, m) < f) {
                    ++m;
                }
                if (g > this.z7) {
                    l.j(this.acp(j, k, n, m - 1));
                }
                else {
                    let o = new OwnedPoint();
                    o.c = { $type: Point_$type, x: j(n), y: k(n) };
                    o.a = this.dn.item(n);
                    if (!a.u.containsKey(o.a)) {
                        a.u.addItem(o.a, o);
                    }
                }
            }
            if (g > this.z7) {
                l.i = null;
            }
        }
        acp(a, b, c, d) {
            if (c == d) {
                return { $type: Point_$type, x: a(c), y: b(c) };
            }
            let e = 0;
            let f = 0;
            let g = (d - c + 1);
            for (let h = c; h <= d; ++h) {
                e += a(h);
                f += b(h);
            }
            return { $type: Point_$type, x: e / g, y: f / g };
        }
        acl(a, b, c, d) {
            let e = a(d) - a(c);
            let f = b(d) - b(c);
            return e * e + f * f;
        }
        get_zo() {
            return true;
        }
        o5(a, b) {
            super.o5(a, b);
            let c = typeCast(ScatterSplineSeriesView.$, b);
            c.c9(false);
        }
        abo(a, b) {
            this.o5(false, b);
            super.abo(a, b);
            this.abg(a);
            let c = typeCast(ScatterSplineSeriesView.$, b);
            let d = c.dl;
            this.y7.az(this, this.zt(), runOn(this, this.yn));
            let e = false;
            let f = this.y7.b;
            if (f != null) {
                e = true;
            }
            if (e) {
                this.aa9(-1, this.zf.count, b.q);
            }
            this.y7.ad(d, true, false, true, false);
            c.dl.an = new PathGeometry();
            c.dl.an.c = Numeric.h(a.m.count, (g) => a.m._inner[g].x, (g) => a.m._inner[g].y, this.acm);
        }
    }
    ScatterSplineSeries.$t = /*@__PURE__*/ markType(ScatterSplineSeries, 'ScatterSplineSeries', ScatterBase.$);
    ScatterSplineSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, ScatterSplineSeries, 'raisePropertyChanged', ['Stiffness:acm:aco', [1, 0.5]]);
    return ScatterSplineSeries;
})();
